@@ -14,20 +14,20 @@ def main():
   parser = argparse.ArgumentParser()
   parser.add_argument('--seed', type=int, default=None)
   parser.add_argument('--area', nargs=2, type=int, default=(64, 64))
-  parser.add_argument('--view', type=int, default=6)
+  parser.add_argument('--view', type=int, nargs=2, default=(23, 13))
   parser.add_argument('--length', type=int, default=None)
   parser.add_argument('--health', type=int, default=5)
-  parser.add_argument('--window', type=int, default=800)
+  parser.add_argument('--window', type=int, nargs=2, default=(1280, 720))
   parser.add_argument('--record', type=str, default=None)
   parser.add_argument('--fps', type=int, default=5)
   args = parser.parse_args()
 
   keymap = {
-      pygame.K_a: 'left',
-      pygame.K_d: 'right',
-      pygame.K_w: 'up',
-      pygame.K_s: 'down',
-      pygame.K_SPACE: 'interact',
+      pygame.K_a: 'move_left',
+      pygame.K_d: 'move_right',
+      pygame.K_w: 'move_up',
+      pygame.K_s: 'move_down',
+      pygame.K_SPACE: 'do',
       pygame.K_1: 'place_stone',
       pygame.K_2: 'place_table',
       pygame.K_3: 'place_furnace',
@@ -42,18 +42,16 @@ def main():
   env = crafter.Env(
       args.area, args.view, args.window, args.length, args.health, args.seed)
   env.reset()
-  inventory = None
-  health = None
   achievements = set()
   return_ = 0
+  was_done = False
   if args.record:
     frames = []
 
-  diamond = crafter.crafter.MATERIAL_IDS['diamond']
-  print('Diamonds exist:', (env._terrain == diamond).sum())
+  print('Diamonds exist:', env._terrain.count('diamond'))
 
   pygame.init()
-  screen = pygame.display.set_mode([args.window, args.window])
+  screen = pygame.display.set_mode(args.window)
   clock = pygame.time.Clock()
   running = True
   while running:
@@ -85,20 +83,14 @@ def main():
       achievements = env._player.achievements.copy()
     if env._step > 0 and env._step % 100 == 0:
       messages.append(f'Time step: {env._step}')
-    if not health or health != env._player.health:
-      health = env._player.health
-      messages.append(f'Health: {health}/{args.health}')
     if reward:
       messages.append(f'Reward: {reward}')
       return_ += reward
-    if done:
-      messages.append(f'Episode end: {done}')
-    if not inventory or inventory != env._player.inventory:
-      inventory = env._player.inventory.copy()
-      content = ', '.join(f'{v} {k}' for k, v in inventory.items())
-      messages.append(f'Inventory: {content}')
+    if done and not was_done:
+      was_done = True
+      messages.append('Episode done')
     if messages:
-      print('\n', '\n'.join(messages), sep='')
+      print('\n'.join(messages), sep='')
 
     if args.record:
       frames.append(obs['image'])
